package com.steerinfo.dil.controller;


import com.steerinfo.dil.mapper.BackgroundProcessingMapper;
import com.steerinfo.dil.service.impl.BackgroundProcessingServiceImpl;
import com.steerinfo.dil.util.BaseRESTfulController;
import com.steerinfo.framework.controller.RESTfulResult;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/*
 * 后台处理程序
 */

@RestController
@RequestMapping("${api.version}/bp")
public class BackgroundProcessingController extends BaseRESTfulController {

    @Autowired
    private BackgroundProcessingMapper backgroundProcessingMapper;

    @Autowired
    private BackgroundProcessingServiceImpl backgroundProcessingService;


    @ApiOperation(value = "关闭一车多趟方法")
    @PostMapping("/closePurOrderMoreTrips")
    public RESTfulResult closePurOrderMoreTrips(String purchaseOrderNo, String deleteNoReceiveOrder) {
        int i = backgroundProcessingMapper.closePurOrderMoreTrips(purchaseOrderNo);
        if("yes".equals(deleteNoReceiveOrder)){
            //查询该采购订单下所有未接收的运输订单（5,6,7,8,17,18)
            ArrayList<Integer> orderIdList = backgroundProcessingMapper.getAllPurOrder(purchaseOrderNo);
            if(orderIdList != null && orderIdList.size() != 0){
                backgroundProcessingMapper.deleteOrders(orderIdList); //物理删除
                backgroundProcessingMapper.deleteOrderMaterials(orderIdList);//物理删除物资子表
                backgroundProcessingMapper.batchByOrderIdForTotalDelete(orderIdList);//总实绩表
            }
        }
        if(i != 1){
            return failed("关闭失败！没有此采购订单");
        }
        return success("关闭成功");
    }

    @ApiOperation(value = "更改所属厂区方法")
    @PostMapping("/updatePurOrgId")
    public RESTfulResult updatePurOrgId(@RequestBody(required = false) Map<String, Object> map){
        return success(backgroundProcessingService.updatePurOrgId(map));
    }

    @ApiOperation(value = "删除没用的表实绩 ")
    @PostMapping("/deleteErrorResult")
    public RESTfulResult deleteErrorResult(String orderNumber){
        return success(backgroundProcessingService.deleteErrorResult(orderNumber));
    }

    @ApiOperation(value = "手动允许放行-OK字段")
    @PostMapping("/allowEnfactory")
    public RESTfulResult allowEnfactory(String orderNumber){
        return success(backgroundProcessingMapper.allowEnfactory(orderNumber));
    }

    @ApiOperation(value = "获取cid和车牌号的关系")
    @PostMapping("/bindCidCapacityNo")
    public RESTfulResult bindCidCapacityNo(String cid,
                                           String capacityNo){
        if(cid == null || capacityNo == null || "null".equals(cid) || "null".equals(capacityNo)){
            return success(0);
        }
        int i = backgroundProcessingService.bindCidCapacityNo(cid,capacityNo);
        return success(i);
    }
}
